@@ -2,10 +2,10 @@ import pandas as pd
 import numpy as np
 import datetime, random
 
-__version__ = '1.0.3' # master file
+__version__ = '1.0.8' # master file
 
 class AKIFlagger:
-    ''' Main flagger to detect patients with acute kidney injury (AKI). This flagger returns patients with AKI according to the `KDIGO guidelines <https://kdigo.org/guidelines/>`_ on changes in creatinine\*. The KDIGO guidelines are as follows:
+    ''' Main logic to detect patients with acute kidney injury (AKI). This flagger returns patients with AKI according to the `KDIGO guidelines <https://kdigo.org/guidelines/>`_ on changes in creatinine\*. The KDIGO guidelines are as follows:
 
         * *Stage 1:* 0.3 mg/dL increase in serum creatinine in < 48 hours OR 50% increase in serum creatinine in < 7 days (168 hours)
         * *Stage 2:* 100% increase in (or doubling of) serum creatinine in < 7 days (168 hours)
@@ -237,7 +237,7 @@ class AKIFlagger:
         # Admission column imputation:
         
         # Admission is defined as the first timestamp where THIS occurs:
-        # two consecutive inpatient creatinine measurements <= 72 hours amart
+        # two consecutive inpatient creatinine measurements <= 72 hours apart
 
         cond1 = tmp.groupby(self.patient_id)[self.time].diff(1).shift(-1) <= pd.Timedelta('72hours') # Time constraint check: ensure the inpatients grouped are w/ in 72 hours from each other
         cond2 = tmp[self.inpatient] & tmp.groupby(self.patient_id)[self.inpatient].shift(-1).astype('bool') # Chunk check: ensure that the True (inpatient) is followed by another True
@@ -254,7 +254,7 @@ class AKIFlagger:
         tmp = tmp.drop('c1c2', axis=1)
         return tmp
     
-    def _eGFRbasedCreatImputation(self, age, female, black): # Deprecated function, not in use internally (yet)
+    def _eGFRbasedCreatImputation(self, age, female, black): # Deprecated function, not in use internally (anymore)
         '''Imputes the baseline creatinine values for those patients missing outpatient creatinine measurements from 365 to 7 days prior to admission.
         The imputation is based on the `CKD-EPI equation <https://www.niddk.nih.gov/health-information/professionals/clinical-tools-patient-management/kidney-disease/laboratory-evaluation/glomerular-filtration-rate/estimating>`_ from the paper
         *A New Equation to Estimate Glomerular Filtration Rate (Levey et. Al, 2009)*.
@@ -296,7 +296,9 @@ class AKIFlagger:
         '''
 
         kappa = (0.9 - 0.2*female)
-        alpha = (-0.543 + 0.302*female)
+        alpha = (-0.302 + 0.061 *female)
+        #creat_over_kappa = 75 / (142*0.012*female*0.9938**age)
+        #alpha = (-0.543 + 0.302*female) # AA fix
         creat_over_kappa = 75/(142*(1 + 0.012*female)*0.9938**age)
 
         # Note that if creat/kappa is < 1 then the equation simplifies to creat_over_kappa = (creat/kappa)**(-1.209)
@@ -446,4 +448,5 @@ def generate_toy_data(num_patients = 100, num_encounters_range = (1, 3), num_tim
         df = df.loc[:,[patient_id, inpatient, time, creatinine]]
         if printMsg:
             print('Successfully generated toy data!\n')
-        return df
\ No newline at end of file
+        return df
+'
